const Joi = require('joi')

module.exports = {
  collection: {
    // project
    collectionType: Joi.string(),
    created: Joi.date(),
    title: Joi.string(),
    status: Joi.string(),
    visibleStatus: Joi.string(),
    customId: Joi.string(),
    invitations: Joi.array(),
    handlingEditor: Joi.object(),
    technicalChecks: Joi.object({
      token: Joi.string(),
      eqa: Joi.boolean(),
    }),
  },
  fragment: [
    {
      fragmentType: Joi.valid('version').required(),
      collectionId: Joi.string().required(),
      created: Joi.date(),
      version: Joi.number(),
      submitted: Joi.date(),
      source: Joi.string(), // TODO: move to a file
      metadata: Joi.object({
        journal: Joi.string(),
        issue: Joi.string(),
        title: Joi.string(),
        abstract: Joi.string(),
        type: Joi.string(),
      }),
      declarations: Joi.object({
        agree: Joi.any(),
      }),
      conflicts: Joi.object({
        hasConflicts: Joi.any().valid(['yes', 'no']),
        message: Joi.string(),
        hasDataAvailability: Joi.any().valid(['yes', 'no']),
        dataAvailabilityMessage: Joi.string(),
        hasFunding: Joi.any().valid(['yes', 'no']),
        fundingMessage: Joi.string(),
      }),
      commentsToReviewers: Joi.string(),
      files: Joi.object({
        manuscript: Joi.any(),
        manuscripts: Joi.array().items(
          Joi.object({
            id: Joi.string(),
            name: Joi.string().required(),
            originalName: Joi.string(),
            type: Joi.string(),
            size: Joi.number(),
            url: Joi.string(),
            signedUrl: Joi.string(),
          }),
        ),
        supplementary: Joi.array().items(
          Joi.object({
            id: Joi.string(),
            name: Joi.string().required(),
            originalName: Joi.string(),
            type: Joi.string(),
            size: Joi.number(),
            url: Joi.string(),
            signedUrl: Joi.string(),
          }),
        ),
        coverLetter: Joi.array().items(
          Joi.object({
            id: Joi.string(),
            name: Joi.string().required(),
            originalName: Joi.string(),
            type: Joi.string(),
            size: Joi.number(),
            url: Joi.string(),
            signedUrl: Joi.string(),
          }),
        ),
        responseToReviewers: Joi.array().items(
          Joi.object({
            id: Joi.string(),
            name: Joi.string().required(),
            originalName: Joi.string(),
            type: Joi.string(),
            size: Joi.number(),
            url: Joi.string(),
            signedUrl: Joi.string(),
          }),
        ),
      }),
      notes: Joi.object({
        fundingAcknowledgement: Joi.string(),
        specialInstructions: Joi.string(),
      }),
      reviewers: Joi.array(),
      lock: Joi.object(),
      decision: Joi.object(),
      authors: Joi.array(),
      invitations: Joi.array(),
      revision: Joi.any(),
      recommendations: Joi.array().items(
        Joi.object({
          id: Joi.string().required(),
          userId: Joi.string().required(),
          recommendationType: Joi.string()
            .valid(['review', 'editorRecommendation'])
            .required(),
          submittedOn: Joi.date(),
          createdOn: Joi.date(),
          updatedOn: Joi.date(),
          recommendation: Joi.string().valid([
            'reject',
            'publish',
            'revise',
            'major',
            'minor',
            'return-to-handling-editor',
          ]),
          comments: Joi.array().items(
            Joi.object({
              content: Joi.string(),
              public: Joi.boolean(),
              files: Joi.array(),
            }),
          ),
        }),
      ),
    },
  ],
  user: {
    orcid: Joi.object(),
    name: Joi.string(),
    username: Joi.string(),
    isConfirmed: Joi.boolean(),
    firstName: Joi.string().allow(''),
    lastName: Joi.string().allow(''),
    affiliation: Joi.string().allow(''),
    country: Joi.string().allow(''),
    title: Joi.string().allow(''),
    teams: Joi.array(),
    editorInChief: Joi.boolean(),
    handlingEditor: Joi.boolean(),
    invitationToken: Joi.string().allow(''),
    confirmationToken: Joi.string().allow(''),
    agreeTC: Joi.boolean(),
    isActive: Joi.boolean(),
    notifications: Joi.object({
      email: Joi.object({
        system: Joi.boolean().default(true),
        user: Joi.boolean().default(true),
      }),
    }),
  },
  team: {
    group: Joi.string(),
  },
}
